astrospice
==========

The ``astrospice`` package contains tools for downloading SPICE kernels and
generating astropy coordinates from them. SPICE kernels are used to describe
the geometry of bodies within the solar system - this includes their orbits and
orientations. For more information, see https://naif.jpl.nasa.gov/naif/

.. note::

  astrospice is currently under development, so the API is subject to
  change. Any changes between versions will be clearly set out in the changelog.
  If you find any bugs or have suggestions for changes/improvements/additions,
  please open an issue at https://github.com/dstansby/astrospice/issues !


.. toctree::
   :maxdepth: 2

   installing
   guide
   auto_examples/index
   reference
   acknowledging
